<?php

namespace App\Http\Controllers;

use App\BasicSetting;
use App\Category;
use App\PaymentLog;
use App\Plan;
use App\Post;
use App\Section;
use App\Signal;
use App\SignalComment;
use App\SignalRating;
use App\Staff;
use App\StaffRequest;
use App\Subscribe;
use App\TraitsFolder\CommonTrait;
use App\TransactionLog;
use App\User;
use App\UserSignal;
use App\SubscribeMessage;
use App\SubscribeMessageCron;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Str;

class DashboardController extends Controller
{
    use CommonTrait;
    public function __construct()
    {
        $this->middleware('auth:admin');
    }

    public function getDashboard()
    {

        $data['page_title'] = "Dashboard";
        $data['signal'] = Signal::all()->count();
        $data['blog'] = Post::all()->count();
        $data['category'] = Category::all()->count();
        $data['user'] = User::all()->count();

        $start = Carbon::parse()->subDays(19);
        $end = Carbon::now();
        $stack = [];
        $date = $start;
        while ($date <= $end) {
            $stack[] = $date->copy();
            $date->addDays(1);
        }
        $dL = [];
        $dV = [];
        foreach (array_reverse($stack) as $d){
            $dL[] .= Carbon::parse($d)->format('dS M');

        }
        foreach (array_reverse($stack) as $d){
            $date = Carbon::parse($d)->format('Y-m-d');
            $start = $date.' '.'00:00:00';
            $end = $date.' '.'23:59:59';
            $dC= Signal::whereBetween('created_at',[$start,$end])->get();
            $dV[] .= count($dC);
        }
        $data['dV'] = $dV;
        $data['dL'] = $dL;


        return view('dashboard.dashboard',$data);
    }

    public function manageUser()
    {
        $data['page_title'] = "Manage User";
        $data['user'] = User::latest()->paginate(10);
        return view('dashboard.manage-user',$data);
    }

    public function blockUser(Request $request)
    {
        $request->validate([
            'block_id' => 'required',
        ]);
        $user = User::findOrFail($request->block_id);
        if ($user->status == 1){
            $user->status = 0;
            $user->save();
        }else{
            $user->status = 1;
            $user->save();
        }
        session()->flash('message','Successfully Done');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function blockEmail(Request $request)
    {

        $request->validate([
            'email_id' => 'required',
        ]);
        $user = User::findOrFail($request->email_id);
        if ($user->email_status == 1){
            $user->email_status = 0;
            $user->save();
        }else{
            $user->email_status = 1;
            $user->save();
        }
        session()->flash('message','Successfully Done');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function blockPhone(Request $request)
    {
        $request->validate([
            'phone_id' => 'required',
        ]);
        $user = User::findOrFail($request->phone_id);
        if ($user->phone_status == 1){
            $user->phone_status = 0;
            $user->save();
        }else{
            $user->phone_status = 1;
            $user->save();
        }
        session()->flash('message','Successfully Done');
        session()->flash('type','success');
        return redirect()->back();
    }
    public function googleRecaptcha()
    {
        $data['page_title'] = 'Google Recaptcha';
        return view('dashboard.google-recaptcha',$data);
    }

    public function updateRecaptcha(Request $request, $id)
    {
        $request->validate([
           'captcha_secret' => 'required',
           'captcha_site' => 'required',
        ]);
        $basic = BasicSetting::first();
        $basic->captcha_status = $request->captcha_status == 'on' ? 1 : 0;
        $basic->captcha_secret = $request->captcha_secret;
        $basic->captcha_site = $request->captcha_site;
        $basic->save();
        session()->flash('message','Captcha Updated Successfully.');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function createUser()
    {
        $data['page_title'] = 'Add new User';
        $data['plan'] = Plan::whereStatus(1)->get();
        $data['country'] = json_decode(file_get_contents(storage_path('json/country.json')), true);
        return view('dashboard.user-create',$data);
    }

    public function submitUser(Request $request)
    {
        $request->validate([
           'name' => 'required',
           'country_code' => 'required',
            'email' => 'required|email|unique:users,email',
            'phone' => 'required|unique:users,phone',
            'plan_id' => 'required',
            'password' => 'required|min:5|confirmed'
        ]);
        $plan = Plan::findOrFail($request->plan_id);
        $in = Input::except('_method','_token','password_confirmation');
        $in['password'] = Hash::make($request->password);
        $in['email_code'] = strtoupper(Str::random('6'));
        $in['telegram_token'] = strtoupper(Str::random('32'));
        if ($plan->plan_type == 1){
            $in['expire_time']  = 1;
        }else{
            $in['expire_time']  = Carbon::parse()->addDays($plan->duration);
        }
        $in['email_status'] = 1;
        $in['phone_code']= rand(11111,99999);
        $in['phone_status'] = 1;
        $in['plan_status'] = $request->plan_status == 'on' ? '1' : '0';

        User::create($in);
        session()->flash('message','User Added Successfully');
        session()->flash('type','success');
        return redirect()->back();

    }

    public function editUser($id)
    {
        $data['page_title'] = 'Edit User';
        $data['user'] = User::findOrFail($id);
        $data['plan'] = Plan::whereStatus(1)->get();
        $data['country'] = json_decode(file_get_contents(storage_path('json/country.json')), true);
        return view('dashboard.user-edit',$data);
    }

    public function updateUser(Request $request)
    {
        $user = User::findOrFail($request->user_id);
        $request->validate([
           'name' => 'required',
           'country_code' => 'required',
            'email' => 'required|email|unique:users,email,'.$user->id,
            'username' => 'required|unique:users,username,'.$user->id,
            'phone' => 'required|unique:users,phone,'.$user->id,
            'plan_id' => 'required'
        ]);
        $user->name = $request->name;
        $user->username = $request->username;
        $user->email = $request->email;
        $user->country_code = $request->country_code;
        $user->phone = $request->phone;
        $chatId = $request->telegram_id;
        $user->plan_status = $request->plan_status == 'on' ? '1' : '0';

        if ($user->telegram_id == null and $request->telegram_id){
            $basic = BasicSetting::first();
            $botToken = $basic->telegram_token;
            $web = 'https://api.telegram.org/bot'.$botToken;
            $url = ($web."/sendMessage?chat_id=".$chatId."&text=Hi, ".$user->name." - Your Telegram Notification Activated Successfully.");
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            $output = curl_exec($ch);
            $updateArray = json_decode($output,true);
            curl_close($ch);
            if($updateArray['ok']){
                $user->telegram_id = $request->telegram_id;
            }
        }elseif ($user->telegram_id != $request->telegram_id){
            $basic = BasicSetting::first();
            $botToken = $basic->telegram_token;
            $web = 'https://api.telegram.org/bot'.$botToken;
            $url = ($web."/sendMessage?chat_id=".$chatId."&text=Hi, ".$user->name." - Your Telegram Notification Activated Successfully.");
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            $output = curl_exec($ch);
            $updateArray = json_decode($output,true);
            curl_close($ch);
            if($updateArray['ok']){
                $user->telegram_id = $request->telegram_id;
            }
        }

        if ($user->plan_id != $request->plan_id){
            $plan = Plan::findOrFail($request->plan_id);
            if ($plan->plan_type == 1){
                $user->expire_time  = 1;
            }else{
                $user->expire_time  = Carbon::parse()->addDays($plan->duration);
            }
            $user->plan_id = $request->plan_id;
        }

        if ($user->up_status == 1){
            $user->up_status = 0;
            $user->up_plan_id = null;
        }

        $user->save();
        session()->flash('message','User Updated Successfully.');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function deleteUser(Request $request)
    {
        $user = User::findOrFail($request->id);
        UserSignal::whereUser_id($user->id)->delete();
        TransactionLog::whereUser_id($user->id)->delete();
        PaymentLog::whereUser_id($user->id)->delete();
        $user->delete();
        session()->flash('message','User Deleted Successfully');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function manageSubscriber()
    {
        $data['page_title'] = 'All Subscriber';
        $data['subscriber'] = Subscribe::latest()->paginate(15);
        return view('dashboard.subscriber',$data);
    }

    public function submitSubscriberMessage(Request $request)
    {
        $request->validate([
           'title' => 'required',
           'message' => 'required',
           'subscriber_ids' => 'array|required'
        ]);

        $in = Input::except('_method','_token','subscriber_ids');
        $subscribe = SubscribeMessage::create($in);

        foreach ($request->subscriber_ids as $sub_id){
            $ss['message_id'] = $subscribe->id;
            $ss['subscriber_id'] = $sub_id;
            SubscribeMessageCron::create($ss);
        }

        session()->flash('message','Subscriber Message Submitted');
        session()->flash('type','success');
        return redirect()->back();

    }

    public function subscriberMessageList()
    {
        $data['page_title'] = 'Subscriber Message List';
        $data['message'] = SubscribeMessage::orderBy('id','desc')->paginate(10);
        return view('dashboard.subscriber-message-list',$data);
    }

    public function subscriberMessageDelete(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        SubscribeMessageCron::whereMessage_id($request->id)->delete();
        SubscribeMessage::destroy($request->id);
        session()->flash('message','Subscriber Message Deleted');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function deleteSubscriber(Request $request)
    {
        $request->validate([
           'id' => 'required'
        ]);
        SubscribeMessageCron::whereSubscriber_id($request->id)->delete();
        Subscribe::destroy($request->id);
        session()->flash('message','Subscriber Deleted Successfully');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function getSubscriberMessage()
    {
        $data['page_title'] = 'Subscriber Message';
        $data['subscriber'] = Subscribe::all();
        return view('dashboard.subscriber-message',$data);
    }

    public function getCurrencyWidget()
    {
        $data['page_title'] = 'Currency Widget';
        return view('dashboard.currency-widget',$data);
    }

    public function submitCurrencyWidget(Request $request)
    {
        $section = Section::first();
        $section->currency_live = $request->currency_live;
        $section->currency_cal = $request->currency_cal;
        $section->save();
        session()->flash('message','Currency Widget Updated Successfully');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function staffRequest()
    {
        $data['page_title'] = "Staff Request";
        $data['user'] = StaffRequest::latest()->paginate(10);
        return view('dashboard.staff-request',$data);
    }

    public function staffrequestApprove(Request $request)
    {
        $request->validate([
           'confirm_id' => 'required'
        ]);
        $stff = StaffRequest::whereUser_id($request->confirm_id)->first();
        $stff->status = 1;
        $stff->save();

        $user = User::findOrFail($request->confirm_id);
        $user->signal_status = 1;
        $user->save();

        session()->flash('message','Staff request Approve.');
        session()->flash('type','success');
        return redirect()->back();
    }
    public function staffrequestReject(Request $request)
    {
        $request->validate([
            'reject_id' => 'required'
        ]);
        $stff = StaffRequest::whereUser_id($request->reject_id)->first();
        $stff->status = 2;
        $stff->save();

        $user = User::findOrFail($request->reject_id);
        $user->signal_status = 3;
        $user->save();

        session()->flash('message','Staff request Reject.');
        session()->flash('type','success');
        return redirect()->back();
    }


    public function getTransactionLog()
    {
        $data['page_title'] = "Transaction Log";
        $data['log'] = TransactionLog::orderBy('id','desc')->paginate(20);
        return view('dashboard.transaction-log',$data);
    }
    public function commentSubmit(Request $request)
    {
        $request->validate([
            'comment' => 'required',
            'signal_id' => 'required'
        ]);
        $in = Input::except('_method','_token');
        $in['user_id'] = 0;
        SignalComment::create($in);
        \session()->flash('message','Comment Submitted Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function ratingSubmit(Request $request)
    {
        $request->validate([
            'comment' => 'required',
            'signal_id' => 'required',
            'rating' => 'required'
        ]);

        $in = Input::except('_method','_token');
        $in['user_id'] = 0;
        SignalRating::create($in);
        \session()->flash('message','Rating Submitted Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function createStaff()
    {
        $data['page_title'] = "Create Staff";
        $data['country'] = json_decode(file_get_contents(storage_path('json/country.json')), true);
        return view('dashboard.staff-create',$data);
    }

    public function submitStaff(Request $request)
    {
        $request->validate([
           'name' => 'required',
           'email' => 'required|email|unique:staff',
           'country_code' => 'required',
           'phone' => 'required',
           'password' => 'required|min:5|confirmed'
        ]);
        $in = Input::except('_method','_token','password_confirmation');
        $in['password'] = Hash::make($request->password);
        $in['status'] = $request->status == 'on' ? 1 : 0;
        Staff::create($in);
        \session()->flash('message','Staff Created Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function manageStaff()
    {
        $data['page_title'] = "All Staff";
        $data['staff'] = Staff::orderBy('id','desc')->paginate(15);
        return view('dashboard.staff-all',$data);
    }

    public function passwordUpdateStaff(Request $request)
    {
        $request->validate([
           'id' => 'required',
           'password' => 'required|min:5|confirmed'
        ]);

        $staff = Staff::findOrFail($request->id);
        $staff->password = Hash::make($request->password);
        $staff->save();

        \session()->flash('message','Staff Password Updated.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function editStaff($id)
    {
        $data['page_title'] = "Edit Staff";
        $data['staff'] = Staff::findOrFail($id);
        $data['country'] = json_decode(file_get_contents(storage_path('json/country.json')), true);
        return view('dashboard.staff-edit',$data);
    }

    public function updateStaff(Request $request)
    {
        $staff = Staff::findOrFail($request->id);
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:staff,email,'.$staff->id,
            'country_code' => 'required',
            'phone' => 'required',
        ]);

        $in = Input::except('_method','_token','id');
        $in['status'] = $request->status == 'on' ? 1 : 0;
        $staff->update($in);
        \session()->flash('message','Staff Updated Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

}
