<?php

namespace App\Http\Controllers;

use App\BasicSetting;
use App\Category;
use App\EmailSetting;
use App\Member;
use App\Menu;
use App\Partner;
use App\Plan;
use App\Post;
use App\Signal;
use App\Slider;
use App\Social;
use App\Speciality;
use App\Subscribe;
use App\Testimonial;
use App\TraitsFolder\CommonTrait;
use App\User;
use App\UserSignal;
use App\SubscribeMessageCron;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class HomeController extends Controller
{
    use CommonTrait;
    public function getIndex()
    {
        $data['page_title'] = "Home Page";
        $data['slider'] = Slider::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['testimonial'] = Testimonial::all();
        $data['member'] = Member::all();
        $data['speciality'] = Speciality::all();
        $data['plan'] = Plan::whereStatus(1)->get();
        $data['total_user'] = User::all()->count();
        $data['total_category'] = Category::all()->count();
        $data['total_blog'] = Post::all()->count();
        $data['total_signal'] = Signal::all()->count();
        $data['social'] = Social::all();
        $data['partner'] = Partner::all();
        $data['blog'] = Post::latest()->take(6)->get();
        $data['menus'] = Menu::all();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.home',$data);
    }

    public function getMenu($id,$slug)
    {
        $data['men'] = Menu::whereId($id)->first();
        $data['page_title'] = $data['men']->name;
        $data['menus'] = Menu::all();
        $data['social'] = Social::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.menus',$data);
    }

    public function getAbout()
    {
        $data['page_title'] = 'About Us';
        $data['menus'] = Menu::all();
        $data['social'] = Social::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['team'] = Member::all();
        $data['plan'] = Plan::whereStatus(1)->get();
        $data['total_user'] = User::all()->count();
        $data['total_category'] = Category::all()->count();
        $data['total_blog'] = Post::all()->count();
        $data['total_signal'] = Signal::all()->count();
        $data['testimonial'] = Testimonial::all();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.about-us',$data);
    }

    public function getContact()
    {
        $data['page_title'] = 'Contact Us';
        $data['menus'] = Menu::all();
        $data['social'] = Social::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.contact-us',$data);
    }

    public function submitContact(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'phone' => 'required',
            'message' => 'required',
        ]);
        $this->sendContact($request->email,$request->name,$request->subject,$request->message,$request->phone);
        session()->flash('message','Contact Message Successfully Send.');
        session()->flash('type','success');
        return redirect()->back();
    }
    public function submitSubscribe(Request $request)
    {
        $request->validate([
            'email' => 'required|email|unique:subscribes,email'
        ]);
        $in = Input::except('_method','_token');
        Subscribe::create($in);
        session()->flash('message','Subscribe Completed.');
        session()->flash('type','success');
        return redirect()->back();
    }

    public function getBlog()
    {
        $data['page_title'] = 'Blog Page';
        $data['blog'] = Post::latest()->paginate(3);
        $data['category'] = Category::whereStatus(1)->get();
        $data['social'] = Social::all();
        $data['popular'] = Post::orderBy('views','desc')->take(15)->get();
        $data['menus'] = Menu::all();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.blog',$data);
    }

    public function detailsBlog($slug)
    {
        $data['page_title'] = 'Blog Details';
        $data['blog'] = Post::whereSlug($slug)->first();
        $data['blog']->views = $data['blog']->views +1;
        $data['category'] = Category::whereStatus(1)->get();
        $data['social'] = Social::all();
        $data['popular'] = Post::orderBy('views','desc')->take(10)->get();
        $data['blog']->save();
        $data['menus'] = Menu::all();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        $data['meta'] = 2;
        return view('home.blog-details',$data);
    }

    public function categoryBlog($slug)
    {
        $category = Category::whereSlug($slug)->first();
        $data['page_title'] = $category->name.' - Blog';
        $data['blog'] = Post::whereCategory_id($category->id)->latest()->paginate(3);
        $data['category'] = Category::whereStatus(1)->get();
        $data['social'] = Social::all();
        $data['popular'] = Post::orderBy('views','desc')->take(15)->get();
        $data['menus'] = Menu::all();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.blog',$data);
    }


    public function getTermCondition()
    {
        $data['page_title'] = "Term And Condition";
        $data['social'] = Social::all();
        $data['menus'] = Menu::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.term-condition',$data);
    }

    public function getPrivacyPolicy()
    {
        $data['page_title'] = "Privacy And Policy";
        $data['social'] = Social::all();
        $data['menus'] = Menu::all();
        $data['category'] = Category::whereStatus(1)->get();
        $data['footer_category'] = Category::whereStatus(1)->take(7)->get();
        $data['footer_blog'] = Post::orderBy('views','desc')->take(7)->get();
        return view('home.privacy-policy',$data);
    }

    public function submitCronSubscribeMessage()
    {

        $lists = SubscribeMessageCron::take(10)->get();

        foreach ($lists as $list) {
            $email = EmailSetting::first();
            $subs = Subscribe::find($list->subscriber_id);
            $mail_val = [
                'email' => $subs->email,
                'name' => '',
                'g_email' => $email->email,
                'g_title' => $email->name,
                'subject' => $list->message->title,
            ];

            $body = $list->message->message;

            Mail::send('emails.email', ['body'=>$body], function ($m) use ($mail_val) {
                $m->from($mail_val['g_email'], $mail_val['g_title']);
                $m->to($mail_val['email'], $mail_val['name'])->subject($mail_val['subject']);
            });

            $list->delete();

            echo "Subscriber Notification Send.<br>";

        }
    }

    public function submitCronJob()
    {
        $user = User::wherePlan_status(1)->where('expire_time','!=',1)->get();
        foreach ($user as $u){
            if ($u->expire_time < Carbon::now()){
                $u->plan_status = 0;
                $u->save();
            }
        }
    }

    public function emailTest()
    {
        $basic = BasicSetting::first();
        $mail_val = [
            'email' => 'hellomrhasan@gmail.com',
            'name' => 'Hasan Rahman',
            'g_email' => $basic->email,
            'g_title' => 'softwarezon@hotmail.com',
            'subject' => "Email Test ",
        ];


        $text = '<h3>Please Verify Your Email-Address.</h3>';

        $body = $basic->email_body;
        $body = str_replace("{{name}}","Hasan Rhaman",$body);
        $body = str_replace("{{message}}",$text,$body);
        $body = str_replace("{{site_title}}",$basic->title,$body);


        Mail::send('emails.email', ['body'=>$body], function ($m) use ($mail_val) {
            $m->from($mail_val['g_email'], $mail_val['g_title']);
            $m->to($mail_val['email'], $mail_val['name'])->subject($mail_val['subject']);
        });
    }

    public function submitCronJobSignal()
    {

        $basic = BasicSetting::first();
        $userSignal = UserSignal::take(10)->get();

        foreach ($userSignal as $us){

            $signal = Signal::findOrFail($us->signal_id);
            $user = User::findOrFail($us->user_id);


            if ($us->telegram_alert == 1){
                $botToken = $basic->telegram_token;
                $web = 'https://api.telegram.org/bot'.$botToken;

                $text = "TITLE : $signal->title\n";
                $text .= "ASSETS : ".$signal->asset->name."\n";
                $text .= "SYMBOL : ".$signal->symbol->name."\n";
                $text .= "TYPE :  ".$signal->type->name."\n";
                $text .= "TF :  ".$signal->frame->name."\n";
                $text .= "ENTRY PRICE : ".$signal->entry."\n";
                $text .= "STOP LOSS : ".$signal->loss."\n";
                $text .= "TAKE PROFIT : ".$signal->profit."\n";
                $text .= "STATUS : ".$signal->status->name."\n\n";

                $textT = urlencode($text);

                if ($signal->image){
                    $path = asset("assets/images/signal/$signal->image");
                    $url = ($web."/sendPhoto?chat_id=".$user->telegram_id."&photo=".$path."&caption=$textT");
                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL, $url);
                    curl_setopt($ch,CURLOPT_USERAGENT,"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13");
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    $resp = curl_exec($ch);
                    curl_close($ch);
                    $response = json_decode($resp);
                }else{
                    $url = ($web."/sendMessage?chat_id=".$user->telegram_id."&text=".$textT."&parse_mode=html");
                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL, $url);
                    curl_setopt($ch,CURLOPT_USERAGENT,"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13");
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                    $resp = curl_exec($ch);
                    curl_close($ch);
                    $response = json_decode($resp);
                }

                echo "Telegram Notification Send.<br>";
            }

            if ($us->email_alert == 1){

                $email = EmailSetting::first();

                $mail_val = [
                    'email' => $user->email,
                    'name' => $user->name,
                    'g_email' => $basic->email,
                    'g_title' => $basic->title,
                    'subject' => "New Signal Receive - $basic->title",
                ];
                $textP = "<h4>YOU RECEIVE A NEW SIGNAL</h4>";
                $text = "TITLE : $signal->title<br>";
                $text .= "ASSETS : ".$signal->asset->name."<br>";
                $text .= "SYMBOL : ".$signal->symbol->name."<br>";
                $text .= "TYPE :  ".$signal->type->name."<br>";
                $text .= "TF :  ".$signal->frame->name."<br>";
                $text .= "ENTRY PRICE : ".$signal->entry."<br>";
                $text .= "STOP LOSS : ".$signal->loss."<br>";
                $text .= "TAKE PROFIT : ".$signal->profit."<br>";
                $text .= "STATUS : ".$signal->status->name."<br><hr>";
                $textP .= $text;
                if ($signal->image){
                    $path = asset("assets/images/signal/$signal->image");
                    $textP .= "<img src=".$path." alt=''><br><hr>";
                }
                $textP .= "$signal->description<br>";

                $body = $email->email_body;

                $body = str_replace("{{name}}",$user->name,$body);
                $body = str_replace("{{message}}",$textP,$body);
                $body = str_replace("{{site_title}}",$basic->title,$body);

                Mail::send('emails.email', ['body'=>$body], function ($m) use ($mail_val) {
                    $m->from($mail_val['g_email'], $mail_val['g_title']);
                    $m->to($mail_val['email'], $mail_val['name'])->subject($mail_val['subject']);
                });
                echo "Email Notification Send.<br>";
            }

            if ($us->sms_alert == 1){
                $api = $basic->smsapi;
                $text = $basic->sms_tem;
                $to = $user->country_code.$user->phone;
                $text = urlencode($text);
                $api = str_replace("{{number}}",$to,$api);
                $api = str_replace("{{message}}",$text,$api);
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $api);
                curl_setopt($ch,CURLOPT_USERAGENT,"Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13");
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                $resp = curl_exec($ch);
                curl_close($ch);
                $response = json_decode($resp);
                echo "Phone Notification Send.<br>";
            }

            $us->delete();

        }
    }

}
