<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Input;
use Intervention\Image\Facades\Image;
use App\PaymentMethod;
use Session;
use File;
use App\Plan;
class PlanController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:admin');
    }

    public function create()
    {
        $data['page_title'] = "Create New Plan";
        return view('plan.create',$data);
    }
    public function store(Request $request)
    {
        $request->validate([
           'name' => 'required|unique:plans,name',
            'price' => 'nullable|numeric',
           'duration' => 'numeric',
           'support' => 'required',
        ]);
        
        $in = Input::except('_method', '_token');
        $in['telegram_status'] = $request->telegram_status == 'on' ? '1' : '0';
        $in['email_status'] = $request->email_status == 'on' ? '1' : '0';
        $in['call_status'] = $request->call_status == 'on' ? '1' : '0';
        $in['coaching_status'] = $request->coaching_status == 'on' ? '1' : '0';
        $in['sms_status'] = $request->sms_status == 'on' ? '1' : '0';
        $in['dashboard_status'] = $request->dashboard_status == 'on' ? '1' : '0';
        $in['status'] = $request->status == 'on' ? '1' : '0';

        Plan::create($in);

        session()->flash('message', 'Plan Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }
    public function index()
    {
        $data['page_title'] = "All Plan";
        $data['plan'] = Plan::all();
        return view('plan.index',$data);
    }
    public function edit($id)
    {
       $data['page_title'] = "Edit Plan";
        $data['plan'] = Plan::findOrFail($id);
        return view('plan.edit',$data);
    }

    public function update(Request $request)
    {

        $r = Plan::find($request->id);
    	$request->validate([
           'name' => 'required|unique:plans,name,'.$r->id,
           'price' => 'nullable|numeric',
           'duration' => 'numeric',
           'support' => 'required',
        ]);
        $in = Input::except('_method','_token','id');
        $in['telegram_status'] = $request->telegram_status == 'on' ? '1' : '0';
        $in['email_status'] = $request->email_status == 'on' ? '1' : '0';
        $in['call_status'] = $request->call_status == 'on' ? '1' : '0';
        $in['coaching_status'] = $request->coaching_status == 'on' ? '1' : '0';
        $in['sms_status'] = $request->sms_status == 'on' ? '1' : '0';
        $in['dashboard_status'] = $request->dashboard_status == 'on' ? '1' : '0';
        $in['status'] = $request->status == 'on' ? '1' : '0';

        $r->update($in);
        session()->flash('message', 'Plan Update Successfully.');
        Session::flash('type', 'success');
        return redirect()->back();
    }
    public function destroy(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $testimonial = Plan::findOrFail($request->id);
        $testimonial->delete();
        session()->flash('message', 'Plan Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }


}
