<?php

namespace App\Http\Controllers;

use App\Asset;
use App\Frame;
use App\SignalComment;
use App\SignalPlan;
use App\SignalRating;
use App\Status;
use App\Symbol;
use App\Telegram;
use App\Type;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;
use Session;
use App\Signal;
use App\Plan;
use App\User;
use App\UserPlan;
use Carbon\Carbon;
use App\BasicSetting;
use DB;
use App\UserSignal;
use App\TraitsFolder\CommonTrait;
class SignalController extends Controller
{
    use CommonTrait;

    public function __construct()
    {
        $this->middleware('auth:admin');
    }

    public function create()
    {
        $data['page_title'] = "Create New Signal";
        $data['asset'] = Asset::whereStatus(1)->get();
        $data['type'] = Type::whereStatus(1)->get();
        $data['status'] = Status::whereStatus(1)->get();
        $data['frame'] = Frame::whereStatus(1)->get();
        $data['symbol'] = Symbol::whereStatus(1)->get();
    	$data['plan'] = Plan::whereStatus(1)->get();
        return view('signal.create',$data);
    }
    public function store(Request $request)
    {
		ini_set('max_execution_time', 900);
		
        $request->validate([
           'title' => 'required',
           'service_id' => 'required',
           'description' => 'required',
            'asset_id' => 'required',
            'symbol_id' => 'required',
            'type_id' => 'required',
            'frame_id' => 'required',
            'status_id' => 'required',
        ]);

        $basic = BasicSetting::first();
        
        $data['title'] = $request->title;
        $data['custom'] = strtoupper(Str::random(16));
        $data['description'] = $request->description;
        $data['asset_id'] = $request->asset_id;
        $data['symbol_id'] = $request->symbol_id;
        $data['type_id'] = $request->type_id;
        $data['frame_id'] = $request->frame_id;
        $data['status_id'] = $request->status_id;
        $data['profit'] = $request->profit;
        $data['loss'] = $request->loss;
        $data['entry'] = $request->entry;
        $data['plan_ids'] = implode(";", $request->service_id);

        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name = $data['custom'];
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name.'.'.$ext;
            $location = ('assets/images/signal').'/'.$image_full_name;
            Image::make($image)->save($location);
            $data['image'] = $image_full_name;
        }

        $sig = Signal::create($data);
        foreach ($request->service_id as $s){
            $sp = new SignalPlan;
            $sp->signal_id = $sig->id;
            $sp->plan_id = $s;
            $sp->save();

            $users = User::wherePlan_status(1)->wherePlan_id($s)->get();

            foreach ($users as $user){

                $us['user_id'] = $user->id;
                $us['signal_id'] = $sig->id;
                $us['plan_id'] = $s;

                $us['telegram_alert'] = 0;
                $us['email_alert'] = 0;
                $us['sms_alert'] = 0;

                if ($basic->telegram_status == 1 and $user->plan->telegram_status == 1 and empty(!$user->telegram_id)){
                    $us['telegram_alert'] = 1;
                }
                if ($basic->email_alert == 1 and $user->plan->email_status == 1 and $user->email_status == 1){
                    $us['email_alert'] = 1;
                }
                if ($basic->phone_alert == 1 and $user->plan->sms_status == 1 and $user->phone_status == 1){
                    $us['sms_alert'] = 1;
                }

                if ($us['telegram_alert'] == 1 or $us['email_alert'] == 1 or $us['sms_alert'] == 1){
                    UserSignal::create($us);
                }
            }
        }

        session()->flash('message', 'Signal Posted Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }
    public function index()
    {
        $data['page_title'] = "All Signal";
        $data['signal'] = Signal::orderBy('id','desc')->paginate(20);
        return view('signal.index',$data);
    }

    public function updateResult(Request $request)
    {
        $request->validate([
           'id' => 'required',
           'status' => 'required'
        ]);

        $signal = Signal::findOrFail($request->id);
        $signal->status = $request->status;
        $signal->save();
        session()->flash('message', 'Signal Result Updated.');
        session()->flash('type', 'success');
        return redirect()->back();
    }
    public function show($id)
    {
       $data['page_title'] = "View Signal";
        $data['signal'] = Signal::findOrFail($id);
        $signalDetails = $data['signal'];
        $data['total_comment'] = SignalComment::whereSignal_id($signalDetails->id)->count();
        $data['comments'] = SignalComment::whereSignal_id($signalDetails->id)->get();
        $data['total_rating'] = SignalRating::whereSignal_id($signalDetails->id)->count();
        $data['sum_rating'] = SignalRating::whereSignal_id($signalDetails->id)->sum('rating');
        if ($data['total_rating'] == 0){
            $data['final_rating'] = 0;
        }else{
            $data['final_rating'] = round($data['sum_rating'] / $data['total_rating']);
        }
        $data['rating'] = SignalRating::whereSignal_id($signalDetails->id)->get();
        $data['user_rating'] = SignalRating::whereSignal_id($signalDetails->id)->whereUser_id(0)->first();
        return view('signal.view',$data);
    }

    public function edit($id)
    {
        $data['page_title'] = "Edit Signal";
        $data['signal'] = Signal::findOrFail($id);
        $data['plan'] = Plan::whereStatus(1)->get();
        $ss = $data['signal']->plan_ids;
        $data['signalPlan'] = explode(';',$ss);
        $data['asset'] = Asset::whereStatus(1)->get();
        $data['type'] = Type::whereStatus(1)->get();
        $data['status'] = Status::whereStatus(1)->get();
        $data['frame'] = Frame::whereStatus(1)->get();
        $data['symbol'] = Symbol::whereStatus(1)->get();
        return view('signal.edit',$data);
    }

    public function update(Request $request)
    {
        $sig = Signal::findOrFail($request->signal_id);

        ini_set('max_execution_time', 900);

        $request->validate([
            'title' => 'required',
            'service_id' => 'required',
            'description' => 'required',
            'asset_id' => 'required',
            'symbol_id' => 'required',
            'type_id' => 'required',
            'frame_id' => 'required',
            'status_id' => 'required',
        ]);

        $basic = BasicSetting::first();

        $data['title'] = $request->title;
        $data['custom'] = strtoupper(Str::random(16));
        $data['description'] = $request->description;
        $data['asset_id'] = $request->asset_id;
        $data['symbol_id'] = $request->symbol_id;
        $data['type_id'] = $request->type_id;
        $data['frame_id'] = $request->frame_id;
        $data['status_id'] = $request->status_id;
        $data['profit'] = $request->profit;
        $data['loss'] = $request->loss;
        $data['entry'] = $request->entry;
        $data['plan_ids'] = implode(";", $request->service_id);

        if($request->hasFile('image')){
            File::delete(('./assets/images/signal').'/'.$sig->image);
            $image = $request->file('image');
            $image_name = $data['custom'];
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name.'.'.$ext;
            $location = ('assets/images/signal').'/'.$image_full_name;
            Image::make($image)->save($location);
            $data['image'] = $image_full_name;
        }

        $sig->update($data);

        SignalPlan::whereSignal_id($sig->id)->delete();
        UserSignal::whereSignal_id($sig->id)->delete();

        foreach ($request->service_id as $s){

            $sp = new SignalPlan();
            $sp->signal_id = $sig->id;
            $sp->plan_id = $s;
            $sp->save();

            $users = User::wherePlan_status(1)->wherePlan_id($s)->get();

            foreach ($users as $user){

                $us['user_id'] = $user->id;
                $us['signal_id'] = $sig->id;
                $us['plan_id'] = $s;

                $us['telegram_alert'] = 0;
                $us['email_alert'] = 0;
                $us['sms_alert'] = 0;

                if ($basic->telegram_status == 1 and $user->plan->telegram_status == 1 and empty(!$user->telegram_id)){
                    $us['telegram_alert'] = 1;
                }
                if ($basic->email_alert == 1 and $user->plan->email_status == 1 and $user->email_status == 1){
                    $us['email_alert'] = 1;
                }
                if ($basic->phone_alert == 1 and $user->plan->sms_status == 1 and $user->phone_status == 1){
                    $us['sms_alert'] = 1;
                }

                if ($us['telegram_alert'] == 1 or $us['email_alert'] == 1 or $us['sms_alert'] == 1){
                    UserSignal::create($us);
                }
            }
        }

        session()->flash('message', 'Signal Update Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }

    public function destroy(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $signal = Signal::findOrFail($request->id);

        SignalPlan::whereSignal_id($signal->id)->delete();
        SignalComment::whereSignal_id($signal->id)->delete();
        SignalRating::whereSignal_id($signal->id)->delete();
        UserSignal::whereSignal_id($signal->id)->delete();
        File::delete(('./assets/images/signal').'/'.$signal->image);
        $signal->delete();
        session()->flash('message', 'Signal Deleted Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }
}
