<?php

namespace App\Http\Controllers;

use App\Asset;
use App\BasicSetting;
use App\Category;
use App\Frame;
use App\Plan;
use App\Post;
use App\Signal;
use App\SignalComment;
use App\SignalPlan;
use App\SignalRating;
use App\Staff;
use App\Status;
use App\Symbol;
use App\Type;
use App\User;
use App\UserSignal;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Str;
use Intervention\Image\Facades\Image;

class StaffController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth:staff');
    }

    public function getDashboard()
    {
        $data['page_title'] = 'Staff Dashboard';
        $data['signal'] = Signal::wherePost_by(Auth::user()->id)->count();
        $data['blog'] = Post::all()->count();
        $data['category'] = Category::all()->count();
        $data['user'] = User::all()->count();

        $start = Carbon::parse()->subDays(19);
        $end = Carbon::now();
        $stack = [];
        $date = $start;
        while ($date <= $end) {
            $stack[] = $date->copy();
            $date->addDays(1);
        }
        $dL = [];
        $dV = [];
        foreach (array_reverse($stack) as $d){
            $dL[] .= Carbon::parse($d)->format('dS M');

        }
        foreach (array_reverse($stack) as $d){
            $date = Carbon::parse($d)->format('Y-m-d');
            $start = $date.' '.'00:00:00';
            $end = $date.' '.'23:59:59';
            $dC= Signal::whereBetween('created_at',[$start,$end])->wherePost_by(Auth::user()->id)->get();
            $dV[] .= count($dC);
        }
        $data['dV'] = $dV;
        $data['dL'] = $dL;

        return view('staff.dashboard',$data);
    }

    public function editProfile()
    {
        $data['page_title'] = "Edit Staff Profile";
        $data['admin'] = Staff::findOrFail(Auth::user()->id);
        $data['country'] = json_decode(file_get_contents(storage_path('json/country.json')), true);
        return view('staff.edit-profile',$data);
    }

    public function updateProfile(Request $request)
    {
        $admin = Staff::findOrFail(Auth::user()->id);
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:staff,email,'.$admin->id,
            'phone' => 'required|min:5|unique:staff,phone,'.$admin->id,
            'image' => 'mimes:png,jpg,jpeg'
        ]);
        $in = Input::except('_method','_token');
        if($request->hasFile('image')){
            $image = $request->file('image');
            $filename = time().'.'.$image->getClientOriginalExtension();
            $location = 'assets/images/' . $filename;
            Image::make($image)->resize(215,215)->save($location);
            if ($admin->image != null){
                $path = './assets/images/';
                $link = $path.$admin->image;
                if (file_exists($link)){
                    unlink($link);
                }
            }
            $in['image'] = $filename;
        }
        $admin->fill($in)->save();
        session()->flash('message','Profile Updated Successfully.');
        session()->flash('title','Success');
        session()->flash('type','success');
        return redirect()->back();
    }
    public function getChangePass()
    {
        $data['page_title'] = "Change Password";
        return view('staff.change-password',$data);
    }
    public function postChangePass(Request $request)
    {
        $this->validate($request, [
            'current_password' =>'required',
            'password' => 'required|min:5|confirmed'
        ]);
        try {
            $c_password = Auth::user()->password;
            $c_id = Auth::user()->id;

            $user = Staff::findOrFail($c_id);

            if(Hash::check($request->current_password, $c_password)){

                $password = Hash::make($request->password);
                $user->password = $password;
                $user->save();
                session()->flash('message', 'Password Changes Successfully.');
                session()->flash('title','success');
                return redirect()->back();
            }else{
                session()->flash('message', 'Current Password Not Match');
                Session::flash('type', 'warning');
                return redirect()->back();
            }

        } catch (\PDOException $e) {
            session()->flash('message', $e->getMessage());
            Session::flash('type', 'warning');
            session()->flash('title','Opps');
            return redirect()->back();
        }

    }

    public function signalCreate()
    {
        $data['plan'] = Plan::whereStatus(1)->get();
        $data['page_title'] = "Create New Signal";
        $data['asset'] = Asset::whereStatus(1)->get();
        $data['type'] = Type::whereStatus(1)->get();
        $data['status'] = Status::whereStatus(1)->get();
        $data['frame'] = Frame::whereStatus(1)->get();
        $data['symbol'] = Symbol::whereStatus(1)->get();
        return view('staff.signal.create',$data);
    }

    public function signalStore(Request $request)
    {
        ini_set('max_execution_time', 900);

        $request->validate([
            'title' => 'required',
            'service_id' => 'required',
            'description' => 'required',
            'asset_id' => 'required',
            'symbol_id' => 'required',
            'type_id' => 'required',
            'frame_id' => 'required',
            'status_id' => 'required',
        ]);

        $basic = BasicSetting::first();

        $data['title'] = $request->title;
        $data['post_by'] = Auth::user()->id;
        $data['custom'] = strtoupper(Str::random(16));
        $data['description'] = $request->description;
        $data['asset_id'] = $request->asset_id;
        $data['symbol_id'] = $request->symbol_id;
        $data['type_id'] = $request->type_id;
        $data['frame_id'] = $request->frame_id;
        $data['status_id'] = $request->status_id;
        $data['profit'] = $request->profit;
        $data['loss'] = $request->loss;
        $data['entry'] = $request->entry;
        $data['plan_ids'] = implode(";", $request->service_id);

        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name = $data['custom'];
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name.'.'.$ext;
            $location = ('assets/images/signal').'/'.$image_full_name;
            Image::make($image)->save($location);
            $data['image'] = $image_full_name;
        }

        $sig = Signal::create($data);
        foreach ($request->service_id as $s){
            $sp = new SignalPlan;
            $sp->signal_id = $sig->id;
            $sp->plan_id = $s;
            $sp->save();

            $users = User::wherePlan_status(1)->wherePlan_id($s)->get();

            foreach ($users as $user){

                $us['user_id'] = $user->id;
                $us['signal_id'] = $sig->id;
                $us['plan_id'] = $s;

                $us['telegram_alert'] = 0;
                $us['email_alert'] = 0;
                $us['sms_alert'] = 0;

                if ($basic->telegram_status == 1 and $user->plan->telegram_status == 1 and empty(!$user->telegram_id)){
                    $us['telegram_alert'] = 1;
                }
                if ($basic->email_alert == 1 and $user->plan->email_status == 1 and $user->email_status == 1){
                    $us['email_alert'] = 1;
                }
                if ($basic->phone_alert == 1 and $user->plan->sms_status == 1 and $user->phone_status == 1){
                    $us['sms_alert'] = 1;
                }

                if ($us['telegram_alert'] == 1 or $us['email_alert'] == 1 or $us['sms_alert'] == 1){
                    UserSignal::create($us);
                }
            }
        }

        session()->flash('message', 'Signal Posted Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }

    public function signalIndex()
    {
        $data['page_title'] = "All Signal";
        $data['signal'] = Signal::wherePost_by(Auth::user()->id)->orderBy('id','desc')->paginate(20);
        return view('staff.signal.index',$data);
    }

    public function signalShow($id)
    {
        $data['page_title'] = "View Signal";
        $data['signal'] = Signal::findOrFail($id);
        $signalDetails = $data['signal'];
        $data['total_comment'] = SignalComment::whereSignal_id($signalDetails->id)->count();
        $data['comments'] = SignalComment::whereSignal_id($signalDetails->id)->get();
        $data['total_rating'] = SignalRating::whereSignal_id($signalDetails->id)->count();
        $data['sum_rating'] = SignalRating::whereSignal_id($signalDetails->id)->sum('rating');
        if ($data['total_rating'] == 0){
            $data['final_rating'] = 0;
        }else{
            $data['final_rating'] = round($data['sum_rating'] / $data['total_rating']);
        }
        $data['rating'] = SignalRating::whereSignal_id($signalDetails->id)->get();
        $data['user_rating'] = SignalRating::whereSignal_id($signalDetails->id)->whereUser_id(0)->first();
        return view('staff.signal.view',$data);
    }

    public function signalEdit($id)
    {
        $data['page_title'] = "Edit Signal";
        $data['signal'] = Signal::findOrFail($id);
        $data['plan'] = Plan::whereStatus(1)->get();
        $ss = $data['signal']->plan_ids;
        $data['signalPlan'] = explode(';',$ss);
        $data['asset'] = Asset::whereStatus(1)->get();
        $data['type'] = Type::whereStatus(1)->get();
        $data['status'] = Status::whereStatus(1)->get();
        $data['frame'] = Frame::whereStatus(1)->get();
        $data['symbol'] = Symbol::whereStatus(1)->get();
        return view('staff.signal.edit',$data);
    }

    public function signalUpdate(Request $request)
    {
        $sig = Signal::findOrFail($request->signal_id);

        ini_set('max_execution_time', 900);

        $request->validate([
            'title' => 'required',
            'service_id' => 'required',
            'description' => 'required',
            'asset_id' => 'required',
            'symbol_id' => 'required',
            'type_id' => 'required',
            'frame_id' => 'required',
            'status_id' => 'required',
        ]);

        $basic = BasicSetting::first();

        $data['title'] = $request->title;
        $data['custom'] = strtoupper(Str::random(16));
        $data['description'] = $request->description;
        $data['asset_id'] = $request->asset_id;
        $data['symbol_id'] = $request->symbol_id;
        $data['type_id'] = $request->type_id;
        $data['frame_id'] = $request->frame_id;
        $data['status_id'] = $request->status_id;
        $data['profit'] = $request->profit;
        $data['loss'] = $request->loss;
        $data['entry'] = $request->entry;
        $data['plan_ids'] = implode(";", $request->service_id);
        $data['post_by'] = Auth::user()->id;
        if($request->hasFile('image')){
            File::delete(('./assets/images/signal').'/'.$sig->image);
            $image = $request->file('image');
            $image_name = $data['custom'];
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name.'.'.$ext;
            $location = ('assets/images/signal').'/'.$image_full_name;
            Image::make($image)->save($location);
            $data['image'] = $image_full_name;
        }
        $sig->update($data);

        SignalPlan::whereSignal_id($sig->id)->delete();
        UserSignal::whereSignal_id($sig->id)->delete();

        foreach ($request->service_id as $s){
            $sp = new SignalPlan();
            $sp->signal_id = $sig->id;
            $sp->plan_id = $s;
            $sp->save();

            $users = User::wherePlan_status(1)->wherePlan_id($s)->get();

            foreach ($users as $user){

                $us['user_id'] = $user->id;
                $us['signal_id'] = $sig->id;
                $us['plan_id'] = $s;

                $us['telegram_alert'] = 0;
                $us['email_alert'] = 0;
                $us['sms_alert'] = 0;

                if ($basic->telegram_status == 1 and $user->plan->telegram_status == 1 and empty(!$user->telegram_id)){
                    $us['telegram_alert'] = 1;
                }
                if ($basic->email_alert == 1 and $user->plan->email_status == 1 and $user->email_status == 1){
                    $us['email_alert'] = 1;
                }
                if ($basic->phone_alert == 1 and $user->plan->sms_status == 1 and $user->phone_status == 1){
                    $us['sms_alert'] = 1;
                }

                if ($us['telegram_alert'] == 1 or $us['email_alert'] == 1 or $us['sms_alert'] == 1){
                    UserSignal::create($us);
                }
            }
        }

        session()->flash('message', 'Signal Update Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }
    public function signalDestroy(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $signal = Signal::findOrFail($request->id);

        SignalPlan::whereSignal_id($signal->id)->delete();
        SignalComment::whereSignal_id($signal->id)->delete();
        SignalRating::whereSignal_id($signal->id)->delete();
        UserSignal::whereSignal_id($signal->id)->delete();
        File::delete(('./assets/images/signal').'/'.$signal->image);
        $signal->delete();
        session()->flash('message', 'Signal Deleted Successfully.');
        session()->flash('type', 'success');
        return redirect()->back();
    }

    public function commentSubmit(Request $request)
    {
        $request->validate([
            'comment' => 'required',
            'signal_id' => 'required'
        ]);
        $in = Input::except('_method','_token');
        $in['user_id'] = -1;
        SignalComment::create($in);
        \session()->flash('message','Comment Submitted Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function ratingSubmit(Request $request)
    {
        $request->validate([
            'comment' => 'required',
            'signal_id' => 'required',
            'rating' => 'required'
        ]);

        $in = Input::except('_method','_token');
        $in['user_id'] = -1;
        SignalRating::create($in);
        \session()->flash('message','Rating Submitted Successfully.');
        \session()->flash('type','success');
        return redirect()->back();
    }

    public function createPost()
    {
        $data['category'] = Category::whereStatus(1)->get();
        $data['page_title'] = "Create New Post";
        return view('staff.post.create',$data);
    }
    public function storePost(Request $request)
    {
        $request->validate([
            'title' => 'required|max:60|unique:posts,title',
            'category' => 'required',
            'image' => 'required|mimes:png,jpeg,jpg',
            'tags' => 'required',
            'description' => 'required',
        ]);

        $data['user_id'] = $request->userId;
        $data['category_id'] = $request->category;
        $data['title'] = $request->title;
        $data['slug'] = str_slug($request->title);
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['fetured'] =  $request->fetured == 'on' ? '1' : '0';

        if($request->hasFile('image')){
            $image = $request->file('image');
            $image_name = str_random(20);
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name . '.' . $ext;
            $location = ('assets/images/post'). '/' . $image_full_name;
            Image::make($image)->resize(800,540)->save($location);
            $data['image'] = $image_full_name;
        }

        Post::create($data);
        session()->flash('message', 'Post Created Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }
    public function indexPost()
    {
        $data['page_title'] = "All Post";
        $data['testimonial'] = Post::orderBy('id','desc')->paginate(10);
        return view('staff.post.index',$data);
    }
    public function editPost($id)
    {
        $data['category'] = Category::whereStatus(1)->get();
        $data['page_title'] = "Edit Post";
        $data['testimonial'] = Post::findOrFail($id);
        return view('staff.post.edit',$data);
    }

    public function updatePost(Request $request)
    {
        $r = Post::find($request->id);
        $request->validate([
            'title' => 'required|max:60|unique:posts,title,'.$r->id,
            'image' => 'mimes:png,jpeg,jpg',
        ]);

        $data['user_id'] = $request->userId;
        $data['category_id'] = $request->category;
        $data['title'] = $request->title;
        $data['slug'] = str_slug($request->title);
        $data['tags'] = $request->tags;
        $data['description'] = $request->description;
        $data['fetured'] =  $request->fetured == 'on' ? '1' : '0';

        if($request->hasFile('image')){
            File::delete(('./assets/images/post'). '/' .$r->image);
            $image = $request->file('image');
            $image_name = str_random(20);
            $ext = strtolower($image->getClientOriginalExtension());
            $image_full_name = $image_name . '.' . $ext;
            $location = ('assets/images/post'). '/' . $image_full_name;
            Image::make($image)->resize(800,540)->save($location);
            $data['image'] = $image_full_name;
        }
        $r->update($data);
        session()->flash('message', 'Post Update Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }
    public function destroyPost(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $testimonial = Post::findOrFail($request->id);
        File::delete(('./assets/images/post'). '/' .$testimonial->image);
        $testimonial->delete();
        session()->flash('message', 'Post Deleted Successfully.');
        Session::flash('type', 'success');
        Session::flash('title', 'Success');
        return redirect()->back();
    }

    public function publishPost(Request $request)
    {
        $request->validate([
            'id' => 'required'
        ]);
        $data = Post::findOrFail($request->id);
        if ($data->status == 1){
            $data->status = 0;
            $data->save();

            session()->flash('message', 'Post Unpublish Successfully.');
            Session::flash('type', 'success');
            Session::flash('title', 'Success');
        }else{
            $data->status = 1;
            $data->save();

            session()->flash('message', 'Post Publish Successfully.');
            Session::flash('type', 'success');
            Session::flash('title', 'Success');
        }
        return redirect()->back();
    }

    public function userList()
    {
        $data['page_title'] = "User List";
        $data['user'] = User::orderBy('id','desc')->paginate(15);
        return view('staff.user-list',$data);
    }

    public function updateSignalResult(Request $request)
    {
        $request->validate([
            'id' => 'required',
            'status' => 'required'
        ]);

        $signal = Signal::findOrFail($request->id);
        $signal->status = $request->status;
        $signal->save();
        session()->flash('message', 'Signal Result Updated.');
        session()->flash('type', 'success');
        return redirect()->back();
    }


}
